@@ -1,17 +1,23 @@
+from typing import TYPE_CHECKING
 import json
 import os
 
-class Settings():
-    def __init__(self, env):
+
+if TYPE_CHECKING:
+    from jdMinecraftLauncher.Environment import Environment
+
+
+class Settings:
+    def __init__(self, env: "Environment"):
         self.language = "default"
         self.newsURL = "https://www.minecraft.net"
         self.enableMultiLaunch = False
         self.extractNatives = False
 
-        if os.path.isfile(os.path.join(env.dataPath,"jdMinecraftLauncher","settings.json")):
-            self.load(os.path.join(env.dataPath,"jdMinecraftLauncher","settings.json"))
+        if os.path.isfile(os.path.join(env.dataDir, "settings.json")):
+            self.load(os.path.join(env.dataDir, "settings.json"))
 
-    def load(self, path):
+    def load(self, path: str):
         try:
             with open(path,"r",encoding="utf-8") as f:
                 data = json.load(f)
@@ -22,7 +28,7 @@ class Settings():
         for key, value in data.items():
             settings[key] = value
         
-    def save(self, path):
+    def save(self, path: str):
         data = vars(self)
         with open(path, 'w', encoding='utf-8') as f:
             json.dump(data, f, ensure_ascii=False, indent=4)
